@@ -15,8 +15,7 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/serializer"
 	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
 	"k8s.io/client-go/tools/clientcmd/api"
-	"k8s.io/klog"
-	"k8s.io/kubectl/pkg/util/templates"
+	"k8s.io/klog/v2"
 
 	configv1 "github.com/openshift/api/config/v1"
 	openshiftcontrolplanev1 "github.com/openshift/api/openshiftcontrolplane/v1"
@@ -34,16 +33,12 @@ type ClusterPolicyController struct {
 	Output io.Writer
 }
 
-var longDescription = templates.LongDesc(`
-	Start the Cluster Policy Controller`)
-
 func NewClusterPolicyControllerCommand(name string, out, errout io.Writer) *cobra.Command {
 	options := &ClusterPolicyController{Output: out}
 
 	cmd := &cobra.Command{
 		Use:   name,
 		Short: "Start the cluster policy controller",
-		Long:  longDescription,
 		Run: func(c *cobra.Command, args []string) {
 			serviceability.StartProfiler()
 
